[![Travis](https://img.shields.io/travis/com/adamltyson/brainio?label=Travis%20CI)](
    https://travis-ci.com/adamltyson/brainio)
[![Coverage Status](https://coveralls.io/repos/github/adamltyson/brainio/badge.svg?branch=master)](https://coveralls.io/github/adamltyson/brainio?branch=master)

# brainio
Loading and saving of brain imaging data.


### To install
```bash
pip install brainio
```
